@@ -190,11 +190,16 @@ int ioc_init(void)
 				/* conventional usage for unsupported device */
 				continue;
 			}
-			if (indirect >= MAX_BLKDEV) {
+			if (indirect > MAX_BLKDEV) {
 				fprintf(stderr, "%s: Indirect major #%u out of range\n",
 					ioconf_name, indirect);
 				continue;
 			}
+			if (major > MAX_BLKDEV) {
+				fprintf(stderr, "%s: Major #%u out of range\n",
+					ioconf_name, major);
+				continue;
+			}
 			if (ioconf[indirect] == NULL) {
 				fprintf(stderr,
 					"%s: Indirect record '%u:%u:%u:...'"
@@ -311,7 +316,8 @@ int ioc_init(void)
 			break;
 
 		case '%':
-			strcpy(blkp->dfmt, dfmt + 1);
+			strncpy(blkp->dfmt, dfmt + 1, IOC_FMTLEN);
+			/* fallthrough to next case */
 		case 'd':
 			blkp->cconv = ioc_ito10;
 			strcat(blkp->dfmt, "%s");
