@@ -1,6 +1,6 @@
 /*
  * mpstat: per-processor statistics
- * (C) 2000-2014 by Sebastien GODARD (sysstat <at> orange.fr)
+ * (C) 2000-2015 by Sebastien GODARD (sysstat <at> orange.fr)
  *
  ***************************************************************************
  * This program is free software; you can redistribute it and/or modify it *
@@ -218,8 +218,9 @@ void write_irqcpu_stats(struct stats_irqcpu *st_ic[], int ic_nr, int dis,
 			char *prev_string, char *curr_string)
 {
 	struct stats_cpu *scc;
-	int j = 0, offset, cpu;
+	int j = 0, offset, cpu, colwidth[NR_IRQS];
 	struct stats_irqcpu *p, *q, *p0, *q0;
+	char fmtspec[MAX_IRQ_LEN];
 
 	/*
 	* Check if number of interrupts has changed.
@@ -253,6 +254,22 @@ void write_irqcpu_stats(struct stats_irqcpu *st_ic[], int ic_nr, int dis,
 		printf("\n");
 	}
 
+	/* Calculate column widths */
+	for (j = 0; j < ic_nr; j++) {
+		p0 = st_ic[curr] + j;
+		if (p0->irq_name[0] != '\0') {
+			/* Width is IRQ name + 2 for the trailing "/s" */
+			colwidth[j] = strlen(p0->irq_name) + 2;
+			/*
+			 * Normal space for printing a number is 14 chars
+			 * (space + 10 digits + period + mantissa).
+			 */
+			if (colwidth[j] < 14) {
+				colwidth[j] = 10;
+			}
+		}
+	}
+
 	for (cpu = 1; cpu <= cpu_nr; cpu++) {
 
 		scc = st_cpu[curr] + cpu;
@@ -305,7 +322,8 @@ void write_irqcpu_stats(struct stats_irqcpu *st_ic[], int ic_nr, int dis,
 				if (!strcmp(p0->irq_name, q0->irq_name) || !interval) {
 					p = st_ic[curr] + (cpu - 1) * ic_nr + j;
 					q = st_ic[prev] + (cpu - 1) * ic_nr + offset;
-					printf(" %10.2f",
+					snprintf(fmtspec, sizeof(fmtspec), " %%%d.2f", colwidth[j]);
+					printf(fmtspec,
 					       S_VALUE(q->interrupt, p->interrupt, itv));
 				}
 				else
