@@ -563,15 +563,14 @@ void stub_print_memory_stats(struct activity *a, int prev, int curr,
 			       (double) avg_frskb / avg_count,
 			       ((double) avg_tlskb / avg_count) -
 			       ((double) avg_frskb / avg_count),
-			       ((double) (avg_tlskb / avg_count)) ?
-			       SP_VALUE((double) (avg_frskb / avg_count),
-					(double) (avg_tlskb / avg_count),
-					(double) (avg_tlskb / avg_count)) :
+			       avg_tlskb ?
+			       SP_VALUE((double) avg_frskb / avg_count,
+					(double) avg_tlskb / avg_count,
+					(double) avg_tlskb / avg_count) :
 			       0.0,
-			       (double) (avg_caskb / avg_count),
-			       (((double) avg_tlskb / avg_count) -
-				((double) avg_frskb / avg_count)) ?
-			       SP_VALUE(0.0, (double) (avg_caskb / avg_count),
+			       (double) avg_caskb / avg_count,
+			       (avg_tlskb != avg_frskb) ?
+			       SP_VALUE(0.0, (double) avg_caskb / avg_count,
 					((double) avg_tlskb / avg_count) -
 					((double) avg_frskb / avg_count)) :
 			       0.0);
@@ -2249,10 +2248,10 @@ void stub_print_huge_stats(struct activity *a, int curr, int dispavg)
 		       (double) avg_frhkb / avg_count,
 		       ((double) avg_tlhkb / avg_count) -
 		       ((double) avg_frhkb / avg_count),
-		       ((double) (avg_tlhkb / avg_count)) ?
-		       SP_VALUE((double) (avg_frhkb / avg_count),
-				(double) (avg_tlhkb / avg_count),
-				(double) (avg_tlhkb / avg_count)) :
+		       avg_tlhkb ?
+		       SP_VALUE((double) avg_frhkb / avg_count,
+				(double) avg_tlhkb / avg_count,
+				(double) avg_tlhkb / avg_count) :
 		       0.0);
 
 		/* Reset average counters */
@@ -2582,3 +2581,43 @@ __print_funct_t print_avg_filesystem_stats(struct activity *a, int prev, int cur
 {
 	stub_print_filesystem_stats(a, 2, TRUE);
 }
+
+/*
+ ***************************************************************************
+ * Display Fibre Channel HBA statistics.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ * @prev	Index in array where stats used as reference are.
+ * @curr	Index in array for current sample statistics.
+ * @itv		Interval of time in jiffies.
+ ***************************************************************************
+ */
+__print_funct_t print_fchost_stats(struct activity *a, int prev, int curr,
+				   unsigned long long itv)
+{
+	int i;
+	struct stats_fchost *sfcc,*sfcp;
+
+	if (dis) {
+		printf("\n%-11s fch_rxf/s fch_txf/s fch_rxw/s fch_txw/s FCHOST\n",
+		       timestamp[!curr]);
+	}
+
+	for (i = 0; i < a->nr; i++) {
+
+		sfcc = (struct stats_fchost *) ((char *) a->buf[curr] + i * a->msize);
+		sfcp = (struct stats_fchost *) ((char *) a->buf[prev] + i * a->msize);
+
+		if (!sfcc->fchost_name[0])
+			/* We are at the end of the list */
+			break;
+
+		printf("%-11s %9.2f %9.2f %9.2f %9.2f %s\n", timestamp[curr],
+		       S_VALUE(sfcp->f_rxframes, sfcc->f_rxframes, itv),
+		       S_VALUE(sfcp->f_txframes, sfcc->f_txframes, itv),
+		       S_VALUE(sfcp->f_rxwords,  sfcc->f_rxwords,  itv),
+		       S_VALUE(sfcp->f_txwords,  sfcc->f_txwords,  itv),
+		       sfcc->fchost_name);
+	}
+}
