@@ -2120,5 +2120,89 @@ void read_filesystem(struct stats_filesystem *st_filesystem, int nbr)
 	fclose(fp);
 }
 
+/*
+ ***************************************************************************
+ * Read Fibre Channel HBA statistics.
+ *
+ * IN:
+ * @st_fc	Structure where stats will be saved.
+ * @nbr		Total number of HBAs.
+ *
+ * OUT:
+ * @st_fc	Structure with statistics.
+ ***************************************************************************
+ */
+void read_fchost(struct stats_fchost *st_fc, int nbr)
+{
+	DIR *dir;
+	FILE *fp;
+	struct dirent *drd;
+	struct stats_fchost *st_fc_i;
+	int fch = 0;
+	char fcstat_filename[MAX_PF_NAME];
+	char line[256];
+	unsigned long rx_frames, tx_frames, rx_words, tx_words;
+
+	/* Each host, if present, will have its own hostX entry within SYSFS_FCHOST */
+	if ((dir = opendir(SYSFS_FCHOST)) == NULL)
+		return; /* No FC hosts */
+
+	/*
+	 * Read each of the counters via sysfs, where they are
+	 * returned as hex values (e.g. 0x72400).
+	 */
+	while (((drd = readdir(dir)) != NULL) && (fch < nbr)) {
+		rx_frames = tx_frames = rx_words = tx_words = 0;
+
+		if (!strncmp(drd->d_name, "host", 4)) {
+
+			snprintf(fcstat_filename, MAX_PF_NAME, FC_RX_FRAMES,
+				 SYSFS_FCHOST, drd->d_name);
+			if ((fp = fopen(fcstat_filename, "r"))) {
+				if (fgets(line, sizeof(line), fp)) {
+					sscanf(line, "%lx", &rx_frames);
+				}
+				fclose(fp);
+			}
+
+			snprintf(fcstat_filename, MAX_PF_NAME, FC_TX_FRAMES,
+				 SYSFS_FCHOST, drd->d_name);
+			if ((fp = fopen(fcstat_filename, "r"))) {
+				if (fgets(line, sizeof(line), fp)) {
+					sscanf(line, "%lx", &tx_frames);
+				}
+				fclose(fp);
+			}
+
+			snprintf(fcstat_filename, MAX_PF_NAME, FC_RX_WORDS,
+				 SYSFS_FCHOST, drd->d_name);
+			if ((fp = fopen(fcstat_filename, "r"))) {
+				if (fgets(line, sizeof(line), fp)) {
+					sscanf(line, "%lx", &rx_words);
+				}
+				fclose(fp);
+			}
+
+			snprintf(fcstat_filename, MAX_PF_NAME, FC_TX_WORDS,
+				 SYSFS_FCHOST, drd->d_name);
+			if ((fp = fopen(fcstat_filename, "r"))) {
+				if (fgets(line, sizeof(line), fp)) {
+					sscanf(line, "%lx", &tx_words);
+				}
+				fclose(fp);
+			}
+
+			st_fc_i = st_fc + fch++;
+			st_fc_i->f_rxframes = rx_frames;
+			st_fc_i->f_txframes = tx_frames;
+			st_fc_i->f_rxwords  = rx_words;
+			st_fc_i->f_txwords  = tx_words;
+			strcpy(st_fc_i->fchost_name, drd->d_name);
+		}
+
+	}
+	closedir(dir);
+}
+
 /*------------------ END: FUNCTIONS USED BY SADC ONLY ---------------------*/
 #endif /* SOURCE_SADC */
