@@ -1,6 +1,6 @@
 /*
  * sysstat - sa_wrap.c: Functions used in activity.c
- * (C) 1999-2014 by Sebastien GODARD (sysstat <at> orange.fr)
+ * (C) 1999-2015 by Sebastien GODARD (sysstat <at> orange.fr)
  *
  ***************************************************************************
  * This program is free software; you can redistribute it and/or modify it *
@@ -19,6 +19,9 @@
  ***************************************************************************
  */
 
+#include <dirent.h>
+#include <string.h>
+
 #include "sa.h"
 #include "rd_stats.h"
 #include "count.h"
@@ -877,6 +880,28 @@ __read_funct_t wrap_read_filesystem(struct activity *a)
 	return;
 }
 
+/*
+ ***************************************************************************
+ * Read Fibre Channel HBA statistics.
+ *
+ * IN:
+ * @a	Activity structure.
+ *
+ * OUT:
+ * @a	Activity structure with statistics.
+ ***************************************************************************
+ */
+__read_funct_t wrap_read_fchost(struct activity *a)
+{
+	struct stats_fchost *st_fc
+		= (struct stats_fchost *) a->_buf0;
+
+	read_fchost(st_fc, a->nr);
+
+	return;
+}
+
+
 /*
  ***************************************************************************
  * Count number of interrupts that are in /proc/stat file.
@@ -1101,3 +1126,25 @@ __nr_t wrap_get_filesystem_nr(struct activity *a)
 
 	return 0;
 }
+
+/*
+ ***************************************************************************
+ * Get number of FC hosts.
+ *
+ * IN:
+ * @a	Activity structure.
+ *
+ * RETURNS:
+ * Number of FC hosts + a pre-allocation constant.
+ ***************************************************************************
+ */
+__nr_t wrap_get_fchost_nr(struct activity *a)
+{
+	__nr_t n = 0;
+
+	if ((n = get_fchost_nr()) >= 0)
+		/* Return a positive number even if no FC hosts have been found */
+		return n + NR_FCHOST_PREALLOC;
+
+	return 0;
+}
